/**
 * Created by douhao on 2016/4/18.
 */
angular.module('case-service',[])
  .factory('caseService',function($http,$q) {
    var transform = [function (data) {
      /**
       * The workhorse; converts an object to x-www-form-urlencoded serialization.
       * @param obj
       * @returns {string}
       */
      var param = function (obj) {
        var query = '';
        var name, value, fullSubName, subName, subValue, innerObj, i;
        for (name in obj) {
          value = obj[name];
          if (value instanceof Array) {
            for (i = 0; i < value.length; ++i) {
              subValue = value[i];
              fullSubName = name + '[' + i + ']';
              innerObj = {};
              innerObj[fullSubName] = subValue;
              query += param(innerObj) + '&';
            }
          } else if (value instanceof Object) {
            for (subName in value) {
              subValue = value[subName];
              fullSubName = name + '[' + subName + ']';
              innerObj = {};
              innerObj[fullSubName] = subValue;
              query += param(innerObj) + '&';
            }
          } else if (value !== undefined && value !== null) {
            query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
          }
        }
        return query.length ? query.substr(0, query.length - 1) : query;
      };
      return angular.isObject(data) && String(data) !== '[object File]' ? param(data) : data;
    }];
    return{
      //查找所有经典病理信息
      findCaseAll: function (caseType,dpTag,current,pageSize,equipmentName,bodyPartsName,order) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/cases",
          params: {
            'caseType':caseType,
            'dpTag':dpTag,
            'currentPage': current,
            'pageSize': pageSize,
            'equipTag': equipmentName,
            'bsTag': bodyPartsName,
            'order':order
          }
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });

        return q.promise;
      },

      //根据ID查找经典病历
      findByCaseId: function(id){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/cases/classic/"+id
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //根据病历ID获取问题
      findQuestionByCaseId: function(id){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/cases/"+id+"/question",
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //根据用户ID和病历ID判断用户是否答过题
      IsUserAnswer:function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/cases/"+caseId+"/isAnswered/"+userId
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //增加答题记录
      changeAnswerHistoryInfo:function(userId,caseId,chooseAnswer,rightAnswer,isRight,thinking){
        var q = $q.defer() ;
        $http({
          method: 'post',
          url: config.new_url + "/cases/answer",
          data: {
            'userId':userId,
            'caseId':caseId,
            'chooseAnswer':chooseAnswer,
            'rightAnswer':rightAnswer,
            'isRight':isRight,
            'answerIdeas':thinking
          }
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //查询错题库
      wrongIsExist:function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/cases/"+caseId+"/isWrong/"+userId,
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //添加错题至错题库
      addWrong:function(userId,caseId,rightAnswer,chooseAnswer,answerIdeas){
        var q = $q.defer() ;
        $http({
          method: 'post',
          url: config.new_url + "/cases/wronganswer",
          data: {
            'userId':userId,
            'caseId':caseId,
            'rightAnswer':rightAnswer,
            'chooseAnswer':chooseAnswer,
            'answerIdeas':answerIdeas
          }
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //增加点赞记录
      addAgree: function(caseId,userId){
        var q = $q.defer() ;
        $http({
          method: 'POST',
          url: config.new_url + "/social/like/"+userId+"/"+caseId+"/1",
        })
        .success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //是否点赞
      isAgree: function(caseId,userId){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/social/islike",
          params: {
            'dataId':caseId,
            'dataType':1,
            'userId':userId,
          }
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //收藏
      collect:function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'post',
          url: config.new_url + "/social/store/0/"+userId+"/"+caseId+"/1",
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //取消收藏
      cancleCollect:function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'post',
          url: config.new_url + "/social/store/1/"+userId+"/"+caseId+"/1",
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //是否收藏
      isCollect: function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/social/isstore",
          params: {
            'userId':userId,
            'dataId':caseId,
            'dataType':1
          }
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //增加阅读量
      readNum:function(userId,caseId){
        var q = $q.defer() ;
        $http({
          method: 'post',
          url: config.new_url + "/social/read/"+userId+"/"+caseId+"/1",
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      },

      //判断是否已阅
      answeredcases:function(userId,caseIds){
        var q = $q.defer() ;
        $http({
          method: 'GET',
          url: config.new_url + "/cases/"+caseIds+"/isRead/"+userId,
        }).success(function (data, status, headers, config) {
          // 当相应准备就绪时调用
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          // 当响应以错误状态返回时调用
          q.reject(data);
        });
        return q.promise;
      }
    }
  })
