angular.module('group-service',[])
  .factory('groupService',function($http,$q) {
    var transform = [function (data) {
      /**
       * The workhorse; converts an object to x-www-form-urlencoded serialization.
       * @param obj
       * @returns {string}
       */
      var param = function (obj) {
        var query = '';
        var name, value, fullSubName, subName, subValue, innerObj, i;
        for (name in obj) {
          value = obj[name];
          if (value instanceof Array) {
            for (i = 0; i < value.length; ++i) {
              subValue = value[i];
              fullSubName = name + '[' + i + ']';
              innerObj = {};
              innerObj[fullSubName] = subValue;
              query += param(innerObj) + '&';
            }
          } else if (value instanceof Object) {
            for (subName in value) {
              subValue = value[subName];
              fullSubName = name + '[' + subName + ']';
              innerObj = {};
              innerObj[fullSubName] = subValue;
              query += param(innerObj) + '&';
            }
          } else if (value !== undefined && value !== null) {
            query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
          }
        }
        return query.length ? query.substr(0, query.length - 1) : query;
      };
      return angular.isObject(data) && String(data) !== '[object File]' ? param(data) : data;
    }];
    return{
      getGroups: function (userId, para) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/fuzzySelect/"+userId+"?queryPara="+para,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      getRecommendGroups: function (userId, size) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/recommend/"+userId+"/"+size,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      getGroupsByUserid: function (userId,queryPara) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/"+userId+"?queryPara="+queryPara,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      getGroupById: function (groupId) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/"+groupId+"/detail",
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      getGroupMembers: function (groupId,queryPara,current,pageSize) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/"+groupId+"/users?queryPara="+queryPara+"&current="+current+"&pageSize="+pageSize,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      updateGroupBanned: function (groupId, value) {
        var q = $q.defer();
        $http({
          method: 'PUT',
          url: config.new_url + "/groups/"+groupId+"/banned/"+value,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      updateGroupHost: function (groupId, userId, value) {
        var q = $q.defer();
        $http({
          method: 'PUT',
          url: config.new_url + "/groups/"+groupId+"/users/"+userId+"/host/"+value,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      deleteGroupMember: function (groupId,userId) {
        var q = $q.defer();
        $http({
          method: 'DELETE',
          url: config.new_url + "/groups/"+groupId+"/users/"+userId,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      getGroupByDataLearnId: function (dataLearnId) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/datalearns/"+dataLearnId+"/group",
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      judgeGroup: function (userId, groupId) {
        var q = $q.defer();
        $http({
          method: 'GET',
          url: config.new_url + "/groups/"+groupId+"/isjoined/"+userId,
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      joinGroup: function (userId, groupId) {
        var q = $q.defer();
        $http({
          method: 'POST',
          url: config.new_url + "/groups/"+groupId+"/users/"+userId
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },

      updateAnnouncement: function (groupId, announcement) {
        var q = $q.defer();
        $http({
          headers: { 'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'},
          transformRequest: transform,
          method: 'POST',
          url: config.new_url + "/groups/"+groupId+"/announcement",
          data: {
            'announcement':announcement
          }
        }).success(function (data, status, headers, config) {
          q.resolve(data);
        }).error(function (data, status, headers, config) {
          q.reject(data);
        });
        return q.promise;
      },
    }
  })
